%This code estimates a random parameters logit model of the Coho choice
%experiment from Lewis, Dundas, Kling, Lew, and Hacker (2019)
%This code generates the main econometric parameter estimates
clear;
global WLength WWidth J Params W Y N U P S BRand1 BRand2 BRand3 BRand4 BRand5 BRand6 RespID
global BRand7 BRand8 BRand9 BRand10

%# of parameters to estimate in base Logit model
Params=9;

%Bring in raw data
W=xlsread('Estimation','Estimation');
[WLength, WWidth]=size(W);

[Y] = Variable_Construction(W); %construct variables used in estimation
N=length(Y);
%Respondent ID (used for Halton Draws)
RespID=Y(:,24); %unique id for each survey respondent

%get starting values for logit
B0=0.1;
B0=B0*ones(Params,1);
%call regular logit log likelihood function to maximize (minimize the negative)
options = optimset('LargeScale','off','Display','iter','MaxFunEvals',10000,'TolX',0.000001,'TolFun',0.000001);
[B1,fval,exitflag,output,grad,hessian] = fminunc(@loglike_choice_start,B0,options);
cov_mat = inv(hessian);
std_err = sqrt(diag(cov_mat));
tstat = B1./std_err;
O1 = [B1 std_err tstat]

%Load count of number of choices for each respondent
U=xlsread('RespondentID_NumObs','RespondentID_NumObs');
%Number of simulations
S=1000;   
%Number of respondents
P=max(RespID(:,1));          %max of respondent ID
%Get Halton draws
[BRand1 BRand2 BRand3 BRand4 BRand5 BRand6 BRand7 BRand8 BRand9 BRand10] = Halton_Draws(N,S,P);

%starting values for RPL
B0=[B1; 0.1; 0.1; 0.1; 0.1; 0.1; 0.1; 0.1; 0.1; 0.1];

%call random parameters liklihood function
options = optimset('LargeScale','off','Display','iter','MaxIter',400,'MaxFunEvals',10000,'TolX',0.000001,'TolFun',0.000001);
[B,fval,exitflag,output,grad,hessian] = fminunc(@RPL_like,B0,options);
cov_mat = inv(hessian);
std_err = sqrt(diag(cov_mat));
tstat = B./std_err;
Q=[B std_err tstat]

