function SLL = RPL_like(B)
%This function includes the simulated likelihood function for the coho model
%estimated using a respondent random effect

global WLength WWidth J Params W Y N U P S BRand1 BRand2 BRand3 BRand4 BRand5 BRand6 RespID
global BRand7 BRand8 BRand9 BRand10

%initialize likelihood
Ln = zeros(P,1);

for i =1:1:S
    
    BR1=BRand1(:,i);        %respondent draws
    BR2=BRand2(:,i);
    BR3=BRand3(:,i);
    BR4=BRand4(:,i);
    BR5=BRand5(:,i);
    BR6=BRand6(:,i);
    BR7=BRand7(:,i);
    BR8=BRand8(:,i);
    BR9=BRand9(:,i);
    BR10=BRand10(:,i);
            
    U0=B(1) + B(18)*BR9; %Status Quo utility

    %interaction (preference space)
    U1S=exp(B(2) + B(10)*BR1); %scale (price) parameter
    U1=B(3)*Y(:,3) + B(4)*Y(:,5) + B(5)*Y(:,7) + B(6)*Y(:,9) + B(7)*Y(:,11);
    U1=U1 + B(8)*Y(:,5).*Y(:,3) + B(9)*Y(:,7).*Y(:,5) - U1S.*Y(:,13);
    U1=U1 + B(11)*Y(:,3).*BR2 + B(12)*Y(:,5).*BR3 + B(13)*Y(:,7).*BR4;
    U1=U1 + B(14)*Y(:,9).*BR5 + B(15)*Y(:,11).*BR6;
    U1=U1 + B(16)*Y(:,5).*Y(:,3).*BR7 + B(17)*Y(:,7).*Y(:,5).*BR8;
    
    U2S=exp(B(2) + B(10)*BR1); %scale (price) parameter
    U2=B(3)*Y(:,4) + B(4)*Y(:,6) + B(5)*Y(:,8) + B(6)*Y(:,10) + B(7)*Y(:,12);
    U2=U2 + B(8)*Y(:,6).*Y(:,4) + B(9)*Y(:,8).*Y(:,6) - U2S.*Y(:,14);
    U2=U2 + B(11)*Y(:,4).*BR2 + B(12)*Y(:,6).*BR3 + B(13)*Y(:,8).*BR3;
    U2=U2 + B(14)*Y(:,10).*BR5 + B(15)*Y(:,12).*BR6;
    U2=U2 + B(16)*Y(:,6).*Y(:,4).*BR7 + B(17)*Y(:,8).*Y(:,6).*BR8;
        
    %denominator of logit probability
    den=exp(U0) + exp(U1) + exp(U2);
    
    %logit probabilities
    PSQ=exp(U0)./den;
    PA1=exp(U1)./den;
    PA2=exp(U2)./den;
        
    F=(PSQ.^(Y(:,15))).*(PA1.^(Y(:,16))).*(PA2.^(Y(:,17))); %unweighted
    %F=(PSQ.^(Y(:,15))).*(PA1.^(Y(:,16))).*(PA2.^(Y(:,17))).*Y(:,25); %weighted
    j=1;
    
    %loop to multiply likelihood for all choices within each respondent
    for k = 1:1:P  %P is number of distinct respondents, so k indexes respondents
        SLn=1;
        Num_Obs=U(k,2);                     %# obs for respondent k
        for j = j:1:(j + (Num_Obs-1))       %loop through observations on respondent k
            SLn=SLn*F(j,1);
        end
        j=j+1;
        MultLn(k,1)=SLn; %a Px1 vector
        
    end
 
    Ln=Ln+MultLn;
    
end

Sim_Ln = (1/S).*Ln;     %average the S simulated likelihoods 
SLL_Pre = log(Sim_Ln);
SLL = (-1)*(SLL_Pre'*ones(P,1));