%This code takes RPL parameter estimates for the Coho choice experiment and
%calculates population-adjusted WTP estimates 
%Read data file with parameter estimates 
B=xlsread('RPL_Params_CovMat','B_PopAdj');
cov_mat=xlsread('RPL_Params_CovMat','cov_mat_PopAdj');

rng(50); %fix random number generator seed for repeatable draws
BR=normrnd(0,1,10000,9); %generate 9 columns of 10,000 draws each from a standard normal
Sims=10000; %Krinsky-Robb simulations
MedianWTP=zeros(Sims,12);

%Simulate WTP
for j=1:1:Sims
    
    %draw from a standard normal to start Krinsky-Robb
    rand_nums=normrnd(0,1,length(B),1);
    %draw a parameter vector for Krinsky-Robb
    B_Sim=B + chol(cov_mat)'*rand_nums;
    
    %adjust for sample and population
    %Percent w 4-yr degree
    for t=19:1:21
        B_Sim(t)=B_Sim(t)*0.3577; %population
    end
    
    %WTP for different programs (no fishing regulation changes)
    WTP(:,1)=((B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(20))*1)./exp(B_Sim(2) + B_Sim(10)*BR(:,1)); %Thr,250,Slow
    WTP(:,2)=((B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(20))*1.75)./exp(B_Sim(2) + B_Sim(10)*BR(:,1)); %Thr,325,Slow
    WTP(:,3)=((B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(20))*2.25)./exp(B_Sim(2) + B_Sim(10)*BR(:,1)); %Thr,325,Slow
    WTP(:,4)=((B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(9) + B_Sim(17)*BR(:,8) + B_Sim(20))*1 + (B_Sim(5)+B_Sim(13)*BR(:,4)) + B_Sim(21) )./exp(B_Sim(2) + B_Sim(10)*BR(:,1)) ; %Thr,250,Quick
    WTP(:,5)=((B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(9) + B_Sim(17)*BR(:,8) + B_Sim(20))*1.75 + (B_Sim(5)+B_Sim(13)*BR(:,4)) + B_Sim(21) )./exp(B_Sim(2) + B_Sim(10)*BR(:,1)) ; %Thr,325,Quick
    WTP(:,6)=((B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(9) + B_Sim(17)*BR(:,8) + B_Sim(20))*2.25 + (B_Sim(5)+B_Sim(13)*BR(:,4)) + B_Sim(21) )./exp(B_Sim(2) + B_Sim(10)*BR(:,1)) ; %Thr,375,Quick
    WTP(:,7)=(B_Sim(3)+B_Sim(11)*BR(:,2) + B_Sim(19) + (B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(8) + B_Sim(16)*BR(:,7) + B_Sim(20))*1.75 )./exp(B_Sim(2) + B_Sim(10)*BR(:,1)) ; %Rec,325,Slow
    WTP(:,8)=(B_Sim(3)+B_Sim(11)*BR(:,2) + B_Sim(19) + (B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(8) + B_Sim(16)*BR(:,7) + B_Sim(20))*2.25 )./exp(B_Sim(2) + B_Sim(10)*BR(:,1)) ; %Rec,375,Slow
    WTP(:,9)=(B_Sim(3)+B_Sim(11)*BR(:,2) + B_Sim(19) + (B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(8) + B_Sim(16)*BR(:,7) + B_Sim(20))*3.75 )./exp(B_Sim(2) + B_Sim(10)*BR(:,1)) ; %Rec,375,Slow
    WTP(:,10)=(B_Sim(3)+B_Sim(11)*BR(:,2) + B_Sim(19) + (B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(8) + B_Sim(16)*BR(:,7) + B_Sim(9) + B_Sim(17)*BR(:,8) + B_Sim(20))*1.75 + (B_Sim(5)+B_Sim(13)*BR(:,4)) + B_Sim(21))./exp(B_Sim(2) + B_Sim(10)*BR(:,1)) ; %Rec,325,Quick
    WTP(:,11)=(B_Sim(3)+B_Sim(11)*BR(:,2) + B_Sim(19) + (B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(8) + B_Sim(16)*BR(:,7) + B_Sim(9) + B_Sim(17)*BR(:,8) + B_Sim(20))*2.25 + (B_Sim(5)+B_Sim(13)*BR(:,4)) + B_Sim(21))./exp(B_Sim(2) + B_Sim(10)*BR(:,1)) ; %Rec,375,Quick
    WTP(:,12)=(B_Sim(3)+B_Sim(11)*BR(:,2) + B_Sim(19) + (B_Sim(4) + B_Sim(12)*BR(:,3) + B_Sim(8) + B_Sim(16)*BR(:,7) + B_Sim(9) + B_Sim(17)*BR(:,8) + B_Sim(20))*3.75 + (B_Sim(5)+B_Sim(13)*BR(:,4)) + B_Sim(21))./exp(B_Sim(2) + B_Sim(10)*BR(:,1)) ; %Rec,525,Quick
   
    MedianWTP(j,:)=(median(WTP))*100;
    
    %WTP for attribute changes, using median of simulated WTP from programs
    WTP_Attributes(j,1)=MedianWTP(j,2)-MedianWTP(j,1); %(Thr,325,Slow) - (Thr,250,Slow)
    WTP_Attributes(j,2)=MedianWTP(j,3)-MedianWTP(j,2); %(Thr,375,Slow) - (Thr,325,Slow)
    WTP_Attributes(j,3)=MedianWTP(j,5)-MedianWTP(j,4); %(Thr,325,Quick) - (Thr,250,Quick)
    WTP_Attributes(j,4)=MedianWTP(j,6)-MedianWTP(j,5); %(Thr,375,Quick) - (Thr,325,Quick)
    WTP_Attributes(j,5)=MedianWTP(j,4)-MedianWTP(j,1); %(Thr,250,Quick) - (Thr,250,Slow)
    WTP_Attributes(j,6)=MedianWTP(j,5)-MedianWTP(j,2); %(Thr,325,Quick) - (Thr,325,Slow)
    WTP_Attributes(j,7)=MedianWTP(j,6)-MedianWTP(j,3); %(Thr,375,Quick) - (Thr,375,Slow)
    WTP_Attributes(j,8)=MedianWTP(j,8)-MedianWTP(j,7); %(Rec,375,Slow) - (Rec,325,Slow)
    WTP_Attributes(j,9)=MedianWTP(j,9)-MedianWTP(j,8); %(Rec,525,Slow) - (Rec,375,Slow)
    WTP_Attributes(j,10)=MedianWTP(j,11)-MedianWTP(j,10); %(Rec,375,Quick) - (Rec,325,Quick)
    WTP_Attributes(j,11)=MedianWTP(j,12)-MedianWTP(j,11); %(Rec,525,Quick) - (Rec,375,Quick)
    WTP_Attributes(j,12)=MedianWTP(j,10)-MedianWTP(j,7); %(Rec,325,Quick) - (Rec,325,Slow)
    WTP_Attributes(j,13)=MedianWTP(j,11)-MedianWTP(j,8); %(Rec,375,Quick) - (Rec,375,Slow)
    WTP_Attributes(j,14)=MedianWTP(j,12)-MedianWTP(j,9); %(Rec,525,Quick) - (Rec,525,Slow)
    WTP_Attributes(j,15)=MedianWTP(j,7)-MedianWTP(j,2); %(Rec,325,Slow) - (Thr,325,Slow)
    WTP_Attributes(j,16)=MedianWTP(j,8)-MedianWTP(j,3); %(Rec,375,Slow) - (Thr,375,Slow)
    WTP_Attributes(j,17)=MedianWTP(j,10)-MedianWTP(j,5); %(Rec,325,Quick) - (Thr,325,Quick)
    WTP_Attributes(j,18)=MedianWTP(j,11)-MedianWTP(j,6); %(Rec,375,Quick) - (Thr,375,Quick)     
    
    
end

MeanMedianWTP=mean(MedianWTP)' %WTP estimates for full programs
sd_MeanMedianWTP=std(MedianWTP)'; %SD of WTP estimates for full programs
MeanWTP_Attributes=mean(WTP_Attributes)'; %WTP estimates for attribute changes
sd_MeanWTP_Attributes=std(WTP_Attributes)'; %SD of WTP estimates for attribute changes

CI=zeros(12,2);
for i=1:1:12
   Test1=sort(MedianWTP(:,i));
   CI(i,1)=Test1(0.025*Sims,1);
   CI(i,2)=Test1(0.975*Sims,1);
end

CI_Attributes=zeros(18,2);
for i=1:1:18
   Test2=sort(WTP_Attributes(:,i));
   CI_Attributes(i,1)=Test2(0.025*Sims,1);
   CI_Attributes(i,2)=Test2(0.975*Sims,1);
end

